@@ -1,10 +1,10 @@
 library(lingtypology)
 context("Tests for iso.lang function")
 
-df <- data.frame(my_langs = c("Adyghe", "Udi"))
+df <- data.frame(my_langs = c("Adyghe", "Udi"), stringsAsFactors = FALSE)
 
 test_that("iso.lang", {
     expect_equal(iso.lang("Adyghe"), c(Adyghe = "ady"))
     expect_equal(iso.lang(c("Adyghe", "Udi")), c(Adyghe = "ady", Udi = "udi"))
-    expect_equal(iso.lang(df), c("ady", "udi"))
+    expect_equal(iso.lang(df), c(my_langs1 = "ady", my_langs2 = "udi"))
 })
